@@ -195,7 +195,7 @@ int authenticate_via_pam( const struct passwd *pw ) {
 
   /* Ask PAM to verify acct_mgmt */
   if( PAM_SUCCESS != pam_acct_mgmt(pam_handle,0) ) {
-    result = 0;  /* user authenticated OK! */
+    result = 0;  
   }
 
   /* We're done with PAM.  Free `pam_handle'. */
