@@ -211,11 +211,11 @@ int restore(char *filename) {
       } else 	
 	      if (verbose && 
 		  (verbose > 1 || !user_only_changed))
-		      fprintf(stderr,"%s reset %s context %s->%s\n",
+		      printf("%s reset %s context %s->%s\n",
 			      progname, filename, (retcontext >= 0 ? prev_context : ""), scontext);
     }
     if (verbose > 1 && customizable>0) {
-	    fprintf(stderr,"%s: %s not reset customized by admin to %s\n",
+	    printf("%s: %s not reset customized by admin to %s\n",
 		      progname, filename, prev_context);
     }
 
@@ -259,7 +259,6 @@ void process(char *buf) {
 int main(int argc, char **argv) {
   int i=0;
   char *file_name=NULL;
-  int errors=0;
   int file=0;
   int opt;
   char buf[PATH_MAX];
