@@ -198,8 +198,8 @@ int match(const char *name, struct stat *sb, char **con)
 void usage(const char * const name)
 {
 	fprintf(stderr,
-		"usage:  %s [-dnqvW] [-o filename] spec_file pathname...\n"
-		"usage:  %s [-c policyfile] spec_file\n"
+		"usage:  %s [-dnqvW] [-o filename] [-r alt_root_path ] spec_file pathname...\n"
+		"usage:  %s -c policyfile spec_file\n"
 		"usage:  %s -s [-dnqvW] [-o filename ] spec_file\n", name, name, name);
 	exit(1);
 }
@@ -382,15 +382,21 @@ void set_rootpath(const char *arg)
 	rootpathlen = len;
 }
 
-int invalidcon(const char *path, unsigned lineno, char *context)
+int canoncon(const char *path, unsigned lineno, char **contextp)
 {
+	char *context = *contextp, *tmpcon;
 	int valid = 1;
 
 	if (policyfile) {
-		valid = (sepol_check_context ((char *) context) >= 0);
-	} else if (security_check_context((char *) context) < 0 && errno != ENOENT) {
-		valid = 0;
-		inc_err();
+		valid = (sepol_check_context (context) >= 0);
+	} else if (security_canonicalize_context(context, &tmpcon) < 0) {
+		if (errno != ENOENT) {
+			valid = 0;
+			inc_err();
+		}
+	} else {
+		free(context);
+		*contextp = tmpcon;
 	}
 
 	if (!valid) {
@@ -411,6 +417,9 @@ int main(int argc, char **argv)
 
 	memset(excludeArray,0, sizeof(excludeArray));
 
+	/* Validate all file contexts during matchpathcon_init. */
+	set_matchpathcon_flags(MATCHPATHCON_VALIDATE);
+
 	/* Process any options. */
 	while ((opt = getopt(argc, argv, "Fc:dlnqrsvWe:o:")) > 0) {
 		switch (opt) {
@@ -435,8 +444,9 @@ int main(int argc, char **argv)
 			fclose(policystream);
 
 			/* Only process the specified file_contexts file, not
-			   any .homedirs or .local files. */
-			set_matchpathcon_flags(MATCHPATHCON_BASEONLY);
+			   any .homedirs or .local files, and do not perform
+			   context translations. */
+			set_matchpathcon_flags(MATCHPATHCON_BASEONLY|MATCHPATHCON_NOTRANS|MATCHPATHCON_VALIDATE);
 			
 			break;
 		}
@@ -513,7 +523,7 @@ int main(int argc, char **argv)
 	/* Use our own invalid context checking function so that
 	   we can support either checking against the active policy or
 	   checking against a binary policy file. */
-	set_matchpathcon_invalidcon(&invalidcon);
+	set_matchpathcon_canoncon(&canoncon);
 
 	/* Load the file contexts configuration and check it. */
 	rc = matchpathcon_init(argv[optind]);
